%define debug_package	%{nil}
%global _build_id_links	none

%define VirtualEnvironment      VE

Summary:	docker-forensics-toolkit - toolkit for performing post-mortem analysis of Docker runtime environments

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		docker-forensics-toolkit
Version:	0.2.0
Release:	3%{?dist}
URL:		https://github.com/docker-forensics-toolkit/toolkit

License:	ASL 2

Group:		Applications/Forensics Tools
Source:		%{name}-%{version}.tar.gz

BuildRoot:	%{_tmppath}/rpm-root-%{name}-v%{version}

BuildRequires:	upx

%if 0%{?amzn}
BuildRequires:  rh-python36-python-virtualenv
BuildRequires:  python3  python3-devel
BuildRequires:  rust
Requires:       rh-python38-python
%endif

%if 0%{?centos} == 8 || 0%{?rhel} == 8
BuildRequires:  python3-virtualenv python38-devel python38
%endif

%if 0%{?centos} == 9 || 0%{?rhel} == 9
BuildRequires:  python3-virtualenv python3-devel python3
%endif

%if 0%{?centos} == 7 && 0%{?amzn} == 0
BuildRequires:  python36-virtualenv
BuildRequires:  rh-python38-python rh-python38-python-devel
Requires:       rh-python38-python
%endif

%if 0%{?fedora}
BuildRequires:  python3-virtualenv python3-devel
%endif

%description
This package contains a toolkit for performing post-mortem analysis of Docker runtime environments based on forensic HDD copies of the docker host system.

Features:
 * mount-image - Mounts the forensic image of the docker host
 * status - Prints status information about the container runtime
 * list-images - Prints images found on the computer
 * show-image-history - Displays the build history of an image
 * show-image-config - Pretty prints the full config file of an image
 * list-containers - Prints containers found on the computer
 * show-container-log - Displays the latest container logfiles
 * show-container-config - Pretty prints the combined container specific config files (config.v2.json and hostconfig.json).
 * mount-container - Mounts the file system of a given container at the given location (overlay2 only)
 * macrobber-container-layer - Extracts file system metadata from the container layer of the given container. Use the output with the 'mactime' tool to create a timeline.
 * macrobber-volumes - Extracts file system metadata from the volumes of the given container. Use the output with the 'mactime' tool to create a timeline.
 * carve-for-deleted-docker-files - Carves the image for deleted Docker files, such as container configs,Dockerfiles and deleted log files. Requires 'scalpel' to be installed.

%prep
%setup 

%build
%if 0%{?amzn}
echo virtualenv -p $(which python3) %{VirtualEnvironment} | scl enable rh-python36 -
%endif

%if 0%{?centos}0%{?amzn} == 70
echo virtualenv-3 -p $(echo which python3 | scl enable rh-python38 -) %{VirtualEnvironment} | scl enable rh-python38 -
%endif

%if 0%{?centos} == 8
virtualenv-3 -p $(which python3.8) %{VirtualEnvironment}
%endif

%if 0%{?centos} == 9
virtualenv -p $(which python3) %{VirtualEnvironment}
%endif

%if 0%{?fedora}
virtualenv %{VirtualEnvironment}
%endif

for p in pip pyinstaller termcolor argcomplete imagemounter
do
        sh -c "source %{VirtualEnvironment}/bin/activate; pip3 install --upgrade \"$p\""
done
sh -c "source %{VirtualEnvironment}/bin/activate; pyinstaller -F dof.spec"

%install
%{__install} -Dp -m755 dist/dof %{buildroot}%{_bindir}/dof

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc README.md USAGE.md
%{_bindir}/*

%changelog
* Mon Jun 29 2020 Lawrence R. Rogers <lrr@cert.org> 0.2.0-1
* Release 0.2.0-1
	Version 0.2.0 - initial release

